summaryrefslogtreecommitdiff
path: root/sql/parse_file.cc
diff options
context:
space:
mode:
authorbell@sanja.is.com.ua <>2004-10-07 01:45:06 +0300
committerbell@sanja.is.com.ua <>2004-10-07 01:45:06 +0300
commit3ef0b19cd374970fb2a3e6e963b779186a1a6fae (patch)
tree1962b7cafa7e8bfcfcdc7410d38cf3144d2a6604 /sql/parse_file.cc
parenta9b759af3ea6d8e03ae64b97f9cca8d3e9dfc4e4 (diff)
downloadmariadb-git-3ef0b19cd374970fb2a3e6e963b779186a1a6fae.tar.gz
fixed & added comments (according to Igor's review and a bit more)
Diffstat (limited to 'sql/parse_file.cc')
-rw-r--r--sql/parse_file.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/sql/parse_file.cc b/sql/parse_file.cc
index d10d395d6e5..16674793b48 100644
--- a/sql/parse_file.cc
+++ b/sql/parse_file.cc
@@ -57,11 +57,11 @@ write_escaped_string(IO_CACHE *file, LEX_STRING *val_s)
if (my_b_append(file, (const byte *)"\\n", 2))
return TRUE;
break;
- case '\0': // problem for some string processing utilites
+ case '\0': // problem for some string processing utilities
if (my_b_append(file, (const byte *)"\\0", 2))
return TRUE;
break;
- case 26: // problem for windows utilites (Ctrl-Z)
+ case 26: // problem for windows utilities (Ctrl-Z)
if (my_b_append(file, (const byte *)"\\z", 2))
return TRUE;
break;
@@ -253,7 +253,7 @@ sql_create_definition_file(const LEX_STRING *dir, const LEX_STRING *file_name,
{
if (old_version != ULONGLONG_MAX && max_versions != 0)
{
- // save buckup
+ // save backup
char path_arc[FN_REFLEN];
// backup old version
char path_to[FN_REFLEN];
@@ -383,9 +383,9 @@ sql_parse_prepare(const LEX_STRING *file_name, MEM_ROOT *mem_root,
}
end= parser->end= parser->buff + len;
- *end= '\0'; // barriaer for more simple parsing
+ *end= '\0'; // barrier for more simple parsing
- // 7 = 5 (TYPE=) + 1 (leter at least of type name) + 1 ('\n')
+ // 7 = 5 (TYPE=) + 1 (letter at least of type name) + 1 ('\n')
if (len < 7 ||
parser->buff[0] != 'T' ||
parser->buff[1] != 'Y' ||